@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.65';
+our $VERSION = '1.66';
 
 use Carp;
 use Data::Dumper;
@@ -255,7 +255,7 @@ sub replace {
         my @file = @{ $p->{file_contents} };
 
         if (! $exec || ref $exec ne 'CODE'){
-            croak "\nDES::replace() requires 'exec => \$cref param\n";
+            confess "\nDES::replace() requires 'exec => \$cref param\n";
         }
 
         my $lines_changed;
@@ -312,7 +312,7 @@ Devel::Examine::Subs
     my $pre_proc = 'module';
 
     if (! $compiler->exists($pre_proc)){
-        croak "pre_proc $pre_proc is not implemented.\n";
+        confess "pre_proc $pre_proc is not implemented.\n";
     }
 
     eval {
